pub struct InvalidMovement;Expand description
Error returned when the parser tries to access an invalid movement. This will likely be an issue in the configuration passed to nightrunner_lib when initializing the parser.