pub struct RequiredEventNotCompleted;Expand description
Event exists but required events haven’t been completed yet. The front-end should handle this error state since this isn’t really an error, but rather an indication that the action is valid.
How to handle this depends on what the front-end should do. An example of this state could be and event where you talk to a subject, but you haven’t yet completed a previous objective. Talking to the subject would be a valid action, but not currently. Story-wise the subject can be somewhere else, or could return a different narrative instad.